#
# spec file for package yp-tools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yp-tools
Version:        4.2.3
Release:        3.19
Summary:        Network Information Service (YP) client utilities
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Productivity/Networking/NIS
URL:            https://github.com/thkukuk/yp-tools
Source:         yp-tools-%{version}.tar.bz2
Source1:        match_printcap
Source2:        yp-tools.conf
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libnsl) >= 1.0.4
BuildRequires:  pkgconfig(libtirpc) >= 1.0.1

%description
This packages contains some useful tools for accessing NIS maps or to
test NIS configurations.

%prep
%setup -q

%build
# Work around use of bad cast
CFLAGS="%{optflags} -Wno-error=cast-align"
%configure --disable-static --with-pic --enable-call-passwd \
	--disable-domainname
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/yp
mv %{buildroot}%{_localstatedir}/yp/nicknames %{buildroot}%{_datadir}/yp/
install -D -m 755 %{SOURCE1} %{buildroot}%{_libexecdir}/yp/match_printcap
install -D -m 644 %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/yp-tools.conf
%find_lang %{name}
%fdupes %{buildroot}/%{_prefix}

%post
# Remove symlink pointing to old location (4.2.3-1.8 and older)
if [ "$1" = "2" ] && test -L %{_localstatedir}/yp/nicknames \
       && [ "$(readlink %{_localstatedir}/yp/nicknames)" = ../../usr/lib/yp/nicknames ]; then
    rm -f %{_localstatedir}/yp/nicknames
fi

%postun
if [ "$1" = "0" ]; then
   test -L %{_localstatedir}/yp/nicknames && rm -f %{_localstatedir}/yp/nicknames ||:
fi

%posttrans
if [ -z ${TRANSACTIONAL_UPDATE} ]; then
  %tmpfiles_create yp-tools.conf
fi

%files -f %{name}.lang
%license COPYING
%doc NEWS README
%{_bindir}/ypcat
%{_bindir}/ypchfn
%{_bindir}/ypchsh
%{_bindir}/ypmatch
%{_bindir}/yppasswd
%{_bindir}/ypwhich
%dir %{_libexecdir}/yp
%{_libexecdir}/yp/match_printcap
%dir %{_datadir}/yp
%{_datadir}/yp/nicknames
%{_prefix}/lib/tmpfiles.d/yp-tools.conf
%{_mandir}/man1/ypcat.1%{?ext_man}
%{_mandir}/man1/ypchfn.1%{?ext_man}
%{_mandir}/man1/ypchsh.1%{?ext_man}
%{_mandir}/man1/ypmatch.1%{?ext_man}
%{_mandir}/man1/yppasswd.1%{?ext_man}
%{_mandir}/man1/ypwhich.1%{?ext_man}
%{_mandir}/man5/nicknames.5%{?ext_man}
%{_mandir}/man8/yppoll.8%{?ext_man}
%{_mandir}/man8/ypset.8%{?ext_man}
%{_mandir}/man8/yp_dump_binding.8%{?ext_man}
%{_sbindir}/yppoll
%{_sbindir}/ypset
%{_sbindir}/yp_dump_binding
%{_sbindir}/yptest

%changelog
* Wed Sep 16 2020 Martin Wilck <mwilck@suse.com>
- Fix dangling /var/yp/nicknames symlink after update
  (boo#1176526)
* Sat Aug 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Use /usr/share/yp and /usr/libexec/yp
* Tue Mar 27 2018 kukuk@suse.de
- Update to version 4.2.3
  - Re-add yptest [issues/#4]
  - Lower compiler warnings [bsc#1084633]
* Fri Feb 23 2018 kukuk@suse.com
- Use %%license instead of %%doc [bsc#1082318]
* Wed Nov  8 2017 kukuk@suse.de
- Cleanup dangling symlinks after de-installation
* Tue Nov  7 2017 kukuk@suse.de
- Prepare for transactional update and read-only root filesystem
  - create /var/yp with tmpfiles.d
* Fri Aug 19 2016 kukuk@suse.de
- Re-add ypdomainname and nisdomainname for SLE12 and Leap 42.x
  [bsc#994532]
* Wed Mar 30 2016 kukuk@suse.de
- Disable ypdomainname and nisdomainname
* Mon Mar 14 2016 kukuk@suse.de
- Update to version 4.2.2
  - revert netdb.h changes
* Mon Mar 14 2016 kukuk@suse.de
- Update to version 4.2.1
  - fix order of configure checks
* Tue Mar  8 2016 kukuk@suse.de
- Update to version 4.2
  - fix compiling with old glibc
  - fix bug in fallback code, if ypbind does not speak v3 protocol
* Wed Mar  2 2016 kukuk@suse.de
- Update to version 4.1
  - allow building only with glibc
  - fix seg.fault in yppoll
  - fix yppasswd to work with IPv6
* Tue Feb  2 2016 kukuk@suse.de
- Update to version 4.0
  - build against external libnsl2
- Drop libnis* and libnss_nis6* sub-packages
* Wed Jan 20 2016 kukuk@suse.de
- Update to version 3.5
  - modify internal interface to avoid cast errors
* Fri May  8 2015 kukuk@suse.de
- Update to version 3.4
  - remove some glibc special macros not working on SLES11
- Require libtirpc >= 0.3.0
* Thu Mar 26 2015 kukuk@suse.de
- Revert changes from Dec 4th and 6th, most of them were wrong.
- Update to version 3.3:
  - fix some linking issues
  - add yp_dump_binding
  - Fix file descriptor leak in libnis
  - Fix wrong fallback for binding files in libnis
  - Fix link order
  - Implement locking for multithreaded applications
* Wed Dec 17 2014 schwab@suse.de
- Avoid error from bad cast
* Sat Dec  6 2014 jengelh@inai.de
- Corrections to the description
* Thu Dec  4 2014 jengelh@inai.de
- Reduce filelists by using wildcards. Remove %%doc (it is implicit
  for documentation paths).
- Run build in parallel, and run fdupes to reduce same files.
* Thu Nov 27 2014 dimstar@opensuse.org
- Filter libc.so.6(GLIBC_PRIVATE) from the requires of libnss_nis6:
  we consciously use glibc internas.
- Do not install libtool archives.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in match_printcap script
* Mon Nov  3 2014 kukuk@suse.de
- Update to version 3.0.1
  - Use very short timeout for clnt_create()
* Mon Nov  3 2014 kukuk@suse.de
- Update to version 3.0
  - fix xdrfile-test.c on 32bit
* Fri Oct 31 2014 kukuk@suse.de
- Update to version 2.99.8
  - Enhance libnis for ypserv
* Thu Oct 30 2014 kukuk@suse.de
- Update to version 2.99.7
  - Rework nss_nis6 dependencys
    (RPM handles glibc provides very special)
  - Some fixes to yp_prot.h for ypserv
* Wed Oct 29 2014 kukuk@suse.de
- Update to version 2.99.6
  - Finish libnis library
  - Add nss_nis6 plugin for glibc
* Tue Oct 28 2014 kukuk@suse.de
- Update to version 2.99.5
  - Implement v3 protocol for ypset
  - Enhance libnis library
* Fri Oct 24 2014 kukuk@suse.de
- Update to version 2.99.4
  - fixes last IPv4 only code (except ypset)
* Fri Oct 24 2014 kukuk@suse.de
- Update to version 2.99.3
  - fixes some bugs to build ypbind
* Fri Oct 24 2014 kukuk@suse.de
- Update to version 2.99.2
  - ypwhich speaks now ypbind v3 protocol
  - Add seperate libnis library
* Tue Oct 21 2014 kukuk@suse.de
- Update to version 2.99.1
  - port to TI-RPC
  - ypwhich and ypset can now use IPv6 to speak with ypbind
* Tue Apr  9 2013 kukuk@suse.de
- Update to version 2.14 (minor bugfix release)
* Mon Apr  8 2013 kukuk@suse.de
- Update to version 2.13 (autoconf meta data update)
* Fri Apr  5 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Feb  4 2012 rschweikert@suse.com
- keep all binaries in /usr (UsrMerge project)
* Wed May 11 2011 kukuk@suse.de
- Don't build against libxcrypt (not necessary).
* Wed Apr 21 2010 kukuk@suse.de
- Update to 2.12: Documentation fixes, fix detection of passwd, chsh
  and chfn.
* Tue Apr 20 2010 kukuk@suse.de
- Update to latest upstream version
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
* Mon Jun 21 2004 kukuk@suse.de
- Update to 2.9 (minor documentation and bug fixes)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Wed Jun 11 2003 kukuk@suse.de
- Use %%find_lang
* Thu May 15 2003 kukuk@suse.de
- Add hint about programs, which cache the domainname, to the
  manual page of domainname. [Bug #18975]
* Fri Jan 17 2003 kukuk@suse.de
- Update to version 2.8 (includes all extra patches)
* Thu Aug 29 2002 kukuk@suse.de
- Make sure strings are NUL terminated after strncpy
* Mon May 27 2002 kukuk@suse.de
- Apply fixes for typos
* Mon May 13 2002 kukuk@suse.de
- Update to yp-tools 2.7 (Add yptest, improve options of ypcat)
- Use libxcrypt
* Wed Oct 31 2001 kukuk@suse.de
- Update to yp-tools 2.6 (fixed setlocale calls)
* Sun Apr 15 2001 schwab@suse.de
- Fix missing declarations.
* Thu Apr 12 2001 kukuk@suse.de
- Change patch and configure call for new gettext version
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Wed Mar 21 2001 kukuk@suse.de
- Update to 2.5
* Thu Nov  2 2000 kukuk@suse.de
- New, split from old ypclients package
